@@ -111,7 +111,7 @@ class ComponentUnknownMessage(BaseComponentMessage):
 
 
 class BaseWeChatComponent(object):
-    API_BASE_URL = 'https://api.weixin.qq.com/cgi-bin'
+    API_BASE_URL = 'http://api.weixin.qq.com/cgi-bin'
 
     def __init__(self,
                  component_appid,
